@@ -37,4 +37,13 @@ def estPremier(n):
                 premier = False
     return premier
 
+def division_euclidienne(devidende, diviseur):
+    """
+    Faire la division euclidienne.
+    """
+    q = devidende // diviseur #quotient
+    r = devidende % diviseur #reste
+    
+    return (q,r)
+    
     
\ No newline at end of file
